Statistical Analysis Functions for TopoBank
===========================================

Purpose
-------

This plugin adds the following analysis functions to Topobank:

- Height/Curvature/Slope Distribution
- Autocorrelation
- Power Spectrum
- Roughness Parameters
- Scale-dependent slope/curvature
- Variable bandwidth

For more information, see our `paper`_.

Installation
------------

For production:

.. code-block:: bash

    pip install topobank-statistics

For development:

Clone project, enter project directory and run

.. code-block:: bash

    pip install -e .[dev]

.. _paper: https://doi.org/10.1088/2051-672X/ac860a

